/* eslint-disable import/no-extraneous-dependencies */
import Vue from 'vue';
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import Multiselect from 'vue-multiselect';
import centered from "@storybook/addon-centered";
Vue.component('multiselect', Multiselect);



const stories = storiesOf('Select', module);
const optionsSingle = ['Canada', 'United Kingdom'];
const optionsObject = [{value: "CA", label: "Canada", color: '#e75264'}, {value: "UK", label: "United Kingdom", color: '#0087c5'}];
const trackByOptions = {
  'label': 'label',
  'value': 'value'
};

stories.addDecorator(centered);
stories.addDecorator(withKnobs);
stories.add('Select - single', () => ({
  components: {Multiselect},
  data() {
    return {
      options: optionsSingle,
      multiple: boolean('multiple', false),
      searchable:boolean('searchable', false),
      disabled:boolean('disabled', false),
      loading:boolean('loading', false),
      value: null

    }
  },
  template: "<div style='width:200px'>" +
    "<multiselect " +
      "v-model='value' " +
      ":options='options' " +
      ":multiple='multiple' " +
      ":disabled='disabled' " +
      ":show-labels='false' " +
      ":loading='loading' " +
      ":searchable='searchable' >" +
    "</multiselect>" +
    "<pre class=\"language-json\"><code>{{ value  }}</code></pre></div>"
}),{
  notes: 'A very simple component',
});

stories.add('Select - object', () => ({
  components: {Multiselect},
  data() {
    return {
      options: optionsObject,
      multiple: boolean('multiple', false),
      searchable:boolean('searchable', false),
      disabled:boolean('disabled', false),
      loading:boolean('loading', false),
      value: null

    }
  },
  template: "<div style='width:200px'>" +
    "<multiselect " +
    "v-model='value' " +
    ":options='options' " +
    ":multiple='multiple' " +
    "label='label' " +
    ":disabled='disabled' " +
    ":show-labels='false' " +
    ":searchable='searchable' " +
    ":loading='loading' " +
    "track-by='value'>" +
    "</multiselect>" +
    "<pre class=\"language-json\"><code>{{ value  }}</code></pre></div>"
}),{
  notes: 'A very simple component',
});

stories.add('Select - custom template', () => ({
  components: {Multiselect},
  data() {
    return {
      options: optionsObject,
      multiple: boolean('multiple', false),
      searchable:boolean('searchable', false),
      disabled:boolean('disabled', false),
      loading:boolean('loading', false),
      value: null

    }
  },
  template: "<div style='width:200px'>" +
    "<multiselect " +
      "v-model='value' " +
      ":options='options' " +
      ":multiple='multiple' " +
      "label='label' " +
      ":disabled='disabled' " +
      ":show-labels='false' " +
      ":searchable='searchable' " +
      ":loading='loading' " +
      "track-by='value'>" +
    "<template slot=\"singleLabel\" slot-scope=\"{ option }\"><span class='sh-select-option-indicator' :style='{background:option.color }'></span> {{ option.label }}</template>" +
    "<template slot=\"option\" slot-scope=\"{ option }\"><span class='sh-select-option-indicator' :style='{background:option.color }'></span> {{ option.label }}</template>" +
    "</multiselect>" +
    "<pre class=\"language-json\"><code>{{ value  }}</code></pre>" +
    "</div>"
}),{
  notes: 'A very simple component',
});
