/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {
  withKnobs,
  text,
  boolean,
} from '@storybook/addon-knobs';

import ShCard from '../components/sh-card/ShCard';
import ShCardHeader from '../components/sh-card/ShCardHeader';
import ShCardBox from '../components/sh-card/ShCardBox';
import ShButton from '../components/sh-button/ShButton';
import ShData from '../components/sh-address/ShData';
import ShTag from '../components/sh-tag/ShTag';
import ShAddress from '../components/sh-address/ShAddress';
import centered from "@storybook/addon-centered";
import {withBackgrounds} from "@storybook/addon-backgrounds";

const stories = storiesOf('Address', module);
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.addDecorator(
  withBackgrounds([
    { name: 'basic', value: '#F5F8FB', default: true }
  ])
);
stories.add('Address', () => ({
  components: { ShCard, ShCardHeader, ShCardBox, ShButton, ShData, ShTag, ShAddress },
  data: () => {
  return {
    iconClass_1: text('iconClass_1', 'sh-icon-account'),
    iconClass_2: text('iconClass_2', 'sh-icon-envelope-outline'),
    iconClass_3: text('iconClass_3', 'sh-icon-phone-outline'),
    content: text('content', 'Marcin Czerwiński'),
    tagClass: text('tagClass', 'sh-tag-gray'),
    tagContent: text('tagContent', 'Brak zgody na newsletter'),
    title: text('title', 'Dane adresowe'),
    address: {
      first_name: 'Jason B.',
      last_name: 'Connors',
      company_name: 'Shoplo',
      phone_number: '+48 502 321 242',
      street: 'Kredytowa 20',
      city: 'Warszawa',
      postal_code: '01-089 ',
      state: 'Mazowieckie',
      country: 'Polska'
    }
  }
},
template: `
 <ShSidebar>
  <ShCard
   :style="{width: '500px', height: 'auto'}"
   slot='sidebarHeader'
  >
    <ShCardHeader
      slot='header'
      cardTitle="Customer">
      <ShButton
       slot='header_action'
       buttonContent="Edit"
       buttonSize="small"
       buttonColor="secondary"
       buttonIcon="sh-icon-edit">  
      </ShButton>
    </ShCardHeader>
    <ShCardBox contentClass="md-12">
      <ShData
       :iconClass='iconClass_1'
       :content='content'>
      </ShData>
      <ShData
        :iconClass='iconClass_2'
        :content='content'>
      </ShData>
      <ShData
        :iconClass='iconClass_3'
        :content='content'>
      </ShData>
      <ShTag
        :class='tagClass'
        :tagContent='tagContent'>
      </ShTag>
    </ShCardBox>
    <ShCardBox contentClass="md-12">
      <ShAddress
        :header='title' 
        :address='address'>
      </ShAddress>
    </ShCardBox>
    <ShCardBox contentClass="md-12">
      <ShAddress
        :header='title' 
        :address='address'>
      </ShAddress>
    </ShCardBox>
  </ShCard>
 </ShSidebar>`,
}),{
  notes: 'A very simple component',
});
