/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import ShButton from '../components/sh-button/ShButton';
import ShButtonGroup from '../components/sh-button/ShButtonGroup';
import centered from "@storybook/addon-centered";


const stories = storiesOf('Button', module);
const buttonColorOptions = {
  'primary': 'primary',
  'secondary': 'secondary',
  'clear-blue': 'clear-blue',
  'clear-gray': 'clear-gray',
  'clear-white': 'clear-white',
  'outline-gray': 'outline-gray'
};
const buttonIconOptions = {
  'none': '',
  'arrow-back': 'sh-icon-arrow-back',
  'add': 'sh-icon-add',
  'search': 'sh-icon-search'
};
const buttonTypeOptions = {
  'button': 'button',
  'submit': 'submit'
};
const buttonSizeOptions = {
  'regular': '',
  'small': 'small',
  'text-only': 'text-only'
};
const groupAlignOptions = {
  'none': '',
  'right': 'right',
  'center': 'center'
};

const contentAlignOptions = {
  'center': 'center',
  'left': 'left',
  'right': 'right',
};

stories.addDecorator(centered);
stories.addDecorator(withKnobs({
  escapeHTML: false,
}));
stories.add('ShButton', () => {
  return {
    components: {ShButton},
    props: {
        buttonColor: { type: String, default: select('buttonColor', buttonColorOptions, 'primary')},
        buttonContent:{type: String,
                  default: text('buttonContent', 'my text prop value')} ,
        buttonIcon: {default:select('buttonIcon', buttonIconOptions, '')},
        buttonSize: {default:select('buttonSize', buttonSizeOptions, '')},
        buttonType: {default:select('buttonType', buttonTypeOptions, '')},
        textAlign: {default:select('textAlign', contentAlignOptions, 'center')},
        isDisabled: {default:boolean('isDisabled', false)},
        isFullWidth: {default:boolean('isFullWidth', false)},
        isIcon: {default:boolean('isIcon', false)},
        isIconLeft: {default:boolean('isIconLeft', false)},
        isLoading:{default: boolean('isLoading', false)}
    },
    template: `
      <div style="width:300px">
        <ShButton
          :buttonColor='buttonColor'
          :buttonContent='buttonContent'
          :textAlign='textAlign'
          :buttonIcon='buttonIcon'
          :buttonSize='buttonSize'
          :buttonType='buttonType'
          :isDisabled='isDisabled'
          :isFullWidth='isFullWidth'
          :isIcon='isIcon'
          :isIconLeft='isIconLeft'
          :isLoading='isLoading'>
        </ShButton>
      </div>
    `
  }
},{
  notes: 'A very simple component',
});

stories.add('ShButtonGroup', () => {
  return {
    components: {ShButton, ShButtonGroup},
    data: () => {
      return {
        align: select('align', groupAlignOptions, 'none'),
        connectedButtons: boolean('connectedButtons', true)
      }
    },
    template: `
    <ShButtonGroup
    :align="align"> 
      <ShButton
      buttonColor="icon-outline-blue"
      buttonIcon="sh-icon-more"
      buttonSize="small"
      :isIcon="true">
      </ShButton>
      <ShButtonGroup
    :align="align"
    :connectedButtons="connectedButtons">
      <ShButton
      buttonColor="icon-outline-blue"
      buttonIcon="sh-icon-arrow-back"
      buttonSize="small"
      :isIcon="true">
      </ShButton>
      <ShButton
      buttonColor="icon-outline-blue"
      buttonIcon="sh-icon-arrow-next"
      buttonSize="small"
      :isIcon="true">
      </ShButton>
    </ShButtonGroup>
    <ShButton
      buttonColor="icon-outline-blue"
      buttonIcon="sh-icon-search"
      buttonSize="small"
      :isIcon="true">
      </ShButton>
      <ShButton
      buttonColor="icon-outline-blue"
      buttonIcon="sh-icon-help"
      buttonSize="small"
      :isIcon="true">
      </ShButton>
    </ShButtonGroup>
    `
  }
},{
  notes: 'A very simple component',
});
