/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import { withBackgrounds } from '@storybook/addon-backgrounds';
import {
  withKnobs,
} from '@storybook/addon-knobs';

import ShCardGroup from '../components/sh-card/ShCardGroup';
import ShCard from '../components/sh-card/ShCard';
import ShCardWidget from '../components/sh-card/ShCardWidget';
import ShCardHeader from '../components/sh-card/ShCardHeader';
import ShCardBox from '../components/sh-card/ShCardBox';
import ShButton from '../components/sh-button/ShButton';
import ShCheckbox from '../components/sh-checkbox/ShCheckbox';
import ShInput from '../components/sh-input/ShInput';
import ShTable from '../components/sh-table/ShTable';
import ShSingleColumnLayout from '../layouts/single-column';
import centered from "@storybook/addon-centered";
import i18n from "../../config/storybook/locale";

const stories = storiesOf('Card', module);

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.addDecorator(
  withBackgrounds([
    { name: 'basic', value: '#F5F8FB', default: true }
  ])
);
stories.add('Default card', () => ({
  components: {ShCard, ShSingleColumnLayout},
  template: `<ShSingleColumnLayout>
<ShCard :style="{width: '500px', height: '150px'}">
</ShCard>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});

stories.add('Card with header', () => ({
  components: {ShCard, ShSingleColumnLayout, ShCardHeader, ShButton},
  template: `<ShSingleColumnLayout>
<ShCard :style="{width: '500px', height: '150px'}">
  <ShCardHeader 
  slot="header"
  cardTitle="Title of the card"
  cardDescription="Descrption"
  >
 <ShButton
 slot="header_action"
 buttonSize="small"
 buttonContent="Delete account"
 ></ShButton>
  </ShCardHeader>
</ShCard>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});

stories.add('Card with header and checkbox', () => ({
  components: {ShCard, ShSingleColumnLayout, ShCardHeader, ShButton, ShCheckbox},
  template: `<ShSingleColumnLayout>
<ShCard :style="{width: '500px', minHeight: '150px'}">
  <ShCardHeader 
  slot="header"
  cardTitle="Title of the card"
  cardDescription="Descrption"
  >
 <ShCheckbox
    checkboxLabelContent="Card title"
    checkboxName="checkbox_name"
    checkboxValue="checkbox_value"
 ></ShCheckbox>
  <h4></h4>
  </ShCardHeader>
</ShCard>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});


stories.add('Card with header and card box', () => ({
  components: {ShCard, ShSingleColumnLayout, ShCardHeader, ShButton, ShCheckbox, ShCardBox, ShInput},
  template: `<ShSingleColumnLayout>
<ShCard :style="{width: '500px', minHeight: '150px'}">
  <ShCardHeader 
  slot="header"
  cardTitle="Title of the card"
  cardDescription="Descrption"
  >
  </ShCardHeader>
   <ShCardBox :contentClass="'md-5'">
      <h4 slot="label">Input label</h4>
      <div>
          <ShInput
          inputName="elo"
          value=""
          ></ShInput>
      </div>
  </ShCardBox>
  
  <ShCardBox :contentClass="'md-5'" label="Input label">
      <div>
          <ShInput
          inputName="elo2"
          value=""
          ></ShInput>
      </div>
  </ShCardBox>
</ShCard>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});

const tableDataSimple = [
  { 'id': 1, 'first_name': 'Jesse', 'last_name': 'Simmons', 'date': '2016-10-15 13:43:27', 'gender': 'Male' },
  { 'id': 2, 'first_name': 'John', 'last_name': 'Jacobs', 'date': '2016-12-15 06:00:53', 'gender': 'Male' },
  { 'id': 3, 'first_name': 'Tina', 'last_name': 'Gilbert', 'date': '2016-04-26 06:26:28', 'gender': 'Female' },
  { 'id': 4, 'first_name': 'Clarence', 'last_name': 'Flores', 'date': '2016-04-10 10:28:46', 'gender': 'Male' },
  { 'id': 5, 'first_name': 'Anne', 'last_name': 'Lee', 'date': '2016-12-06 14:38:38', 'gender': 'Female' }
];
const columns = [
  {
    field: 'id',
    label: 'ID',
    width: '40',
  },
  {
    field: 'first_name',
    label: 'First Name',
    align: 'right'
  },
  {
    field: 'last_name',
    label: 'Last Name',
    align: 'center'
  },
  {
    field: 'date',
    label: 'Date',
    centered: true
  },
  {
    field: 'gender',
    label: 'Gender',
  }
];


stories.add('Card with header and table', () => ({
  components: {ShCard, ShSingleColumnLayout, ShCardHeader, ShTable},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
    }
  },
  template: `<ShSingleColumnLayout>
<ShCard :style="{width: '800px', minHeight: '250px'}" :isPaddingLess="true">
  <ShCardHeader 
  slot="header"
  cardTitle="Title of the card"
  cardDescription="Descrption"
  >
  </ShCardHeader>
  <ShTable 
    :data='data'
    :columns='columns'
    >
    </ShTable>
</ShCard>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});

stories.add('Card group', () => ({
  components: {ShCardGroup, ShCard, ShCardWidget, ShSingleColumnLayout, ShCardHeader, ShTable, ShButton},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
    }
  },
  template: `<ShSingleColumnLayout>
<ShCardGroup>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
  <div class="sm-6 md-4 lg-3 column">
    <ShCard>
      <ShCardWidget
        title="Title"
        description="Description"
        type="box"
      >
         <ShButton
          slot="action"
          buttonContent="Add"
          buttonSize="small"
        ></ShButton>
      </ShCardWidget>
    </ShCard>
  </div>
</ShCardGroup>
</ShSingleColumnLayout>`,
}),{
  notes: 'A very very simple component',
});
