/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
} from '@storybook/addon-knobs';

import ShCheckbox from '../components/sh-checkbox/ShCheckbox';
import ShCheckboxGroup from '../components/sh-checkbox/ShCheckboxGroup';
import centered from "@storybook/addon-centered";

const checkboxGroupListTypeOptions = {
  'inline': 'inline',
  'block': 'block'
};

const stories = storiesOf('Checkbox', module);
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Regular checkbox', () => ({
  components: {ShCheckbox},
  data: () => {
    return {
      checkboxLabelContent: text('checkboxLabelContent', 'Checkbox label content'),
      checkboxName: text('checkboxName', 'sh_checkbox'),
      checkboxValue: text('checkboxValue', 'Checkbox value'),
      checkboxTrueValue: text('checkboxTrueValue', 'Checkbox true value'),
      checkboxFalseValue: text('checkboxFalseValue', 'Checkbox false value'),
      disabled: boolean('disabled', false),
      isRequired: boolean('isRequired', false),
      isSwitch: boolean('isSwitch', false),
      checkboxLabelContent2: text('checkboxLabelContent2', 'Checkbox 2 label content'),
      checkboxValue2: text('checkboxValue2', 'Checkbox 2 value'),
      checkboxTrueValue2: text('checkboxTrueValue2', 'Checkbox 2 true value'),
      checkboxFalseValue2: text('checkboxFalseValue2', 'Checkbox 2 false value'),
      value: null,
    }
  },
  template: "<div>" +
    "<ShCheckbox " +
    ":checkboxLabelContent='checkboxLabelContent'" +
    ":checkboxName='checkboxName' " +
    ":checkboxValue='checkboxValue'" +
    ":checkboxTrueValue='checkboxTrueValue'" +
    ":checkboxFalseValue='checkboxFalseValue'" +
    ":disabled='disabled'" +
    ":isRequired='isRequired'" +
    ":isSwitch='isSwitch'" +
    "v-model='value'>" +
    "</ShCheckbox>" +
    "<pre class=\"language-json\"><code>{{ value }}</code></pre>" +
    "</div>"
}),{
  notes: 'A very simple component',
});
stories.add('Switch', () => ({
  components: {ShCheckbox},
  data: () => {
    return {
      checkboxLabelContent: text('checkboxLabelContent', 'Switch label content'),
      checkboxName: text('checkboxName', 'sh_checkbox'),
      checkboxValue: text('checkboxValue', 'Switch value'),
      checkboxTrueValue: text('checkboxTrueValue', 'Switch true value'),
      checkboxFalseValue: text('checkboxFalseValue', 'Switch false value'),
      disabled: boolean('disabled', false),
      isRequired: boolean('isRequired', false),
      isSwitch: boolean('isSwitch', true),
      value: null,
    }
  },
  template: "<div>" +
    "<ShCheckbox " +
    ":checkboxLabelContent='checkboxLabelContent'" +
    ":checkboxName='checkboxName' " +
    ":checkboxValue='checkboxValue'" +
    ":checkboxTrueValue='checkboxTrueValue'" +
    ":checkboxFalseValue='checkboxFalseValue'" +
    ":disabled='disabled'" +
    ":isRequired='isRequired'" +
    ":isSwitch='isSwitch'" +
    "v-model='value'>" +
    "</ShCheckbox>" +
    "<pre class=\"language-json\"><code>{{ value }}</code></pre>" +
    "</div>"
}),{
  notes: 'A very simple component',
});

stories.add('Checkbox group', () => ({
  components: {ShCheckbox, ShCheckboxGroup},
  data: () => {
    return {
      isWithColumns: boolean('isWithColumns', true),
      value: [],
    }
  },
  template: `<div>
      <ShCheckboxGroup :isWithColumns="isWithColumns">
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 1 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 1 value"
        checkboxTrueValue="Checkbox 1 true value"
        checkboxFalseValue="Checkbox 1 false value"
        v-model="value">
        </ShCheckbox>
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 2 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 2 value"
        checkboxTrueValue="Checkbox 2 true value"
        checkboxFalseValue="Checkbox 2 false value"
        v-model="value">
        </ShCheckbox>
        <ShCheckbox
        class="sm-12 md-3 lg-4 column"
        checkboxLabelContent="Checkbox 3 label content"
        checkboxName="checkbox_name" 
        checkboxValue="Checkbox 3 value"
        checkboxTrueValue="Checkbox 3 true value"
        checkboxFalseValue="Checkbox 3 false value"
        v-model="value">
        </ShCheckbox>
      </ShCheckboxGroup>
      <pre class="language-json"><code>{{ value }}</code></pre>
    </div>`
}),{
  notes: 'A very simple component',
});
