/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';

import ShModal from '../components/sh-modal/ShModal';
import ShButton from '../components/sh-button/ShButton';
import centered from "@storybook/addon-centered";
const animationTypes = {
  'zoom-out': 'zoom-out',
  'zoom-in': 'zoom-in',
  'fade': 'fade'
};
const stories = storiesOf('Dialog', module);

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Confirm', () => ({
  components: {ShModal, ShButton},
  data: () => {
    return {
      active: boolean('active', false),
      animation: select('animation', animationTypes, 'zoom-out'),
      width: number('width',400),
      hasModalCard: boolean('hasModalCard', true),
      content: text('content', 'You have unsaved changes. Are you sure to leave this page?'),
      modalCardHeader: text('modalCardHeader', 'Confirmation'),
      modalCardHeaderIcon: boolean('modalCardHeaderIcon', true),
      modalCardConfirm: text('modalCardConfirm', 'Confirm'),
      modalCardCancel: text('modalCardCancel', 'Cancel'),
    }
  },
  template: `
  <div>
  <ShButton @click="showConfirm" buttonContent="Show alert"></ShButton>
</div>
`,
  methods: {
    showConfirm() {
      this.$dialog.confirm({
        content: this.content,
        animation: this.animation,
        width: this.width,
        modalCardHeader: this.modalCardHeader,
        modalCardHeaderIcon: this.modalCardHeaderIcon,
        modalCardConfirm: this.modalCardConfirm,
        modalCardCancel: this.modalCardCancel,
        onConfirm: () => {
          console.log('confirm')
        }
      });
    }
  }
}),{
  notes: 'A very very simple component',
});

stories.add('Alert', () => ({
  components: {ShModal, ShButton},
  data: () => {
    return {
      active: boolean('active', false),
      animation: select('animation', animationTypes, 'zoom-out'),
      width: number('width',400),
      hasModalCard: boolean('hasModalCard', true),
      content: text('content', 'Save the settings to proceed'),
      modalCardHeader: text('modalCardHeader', 'Alert'),
      modalCardHeaderIcon: boolean('modalCardHeaderIcon', true),
      modalCardConfirm: text('modalCardConfirm', 'OK'),
    }
  },
  template: `
  <div>
  <ShButton @click="showAlert" buttonContent="Show alert"></ShButton>
</div>
`,
  methods: {
    showAlert() {
      this.$dialog.alert({
        content: this.content,
        animation: this.animation,
        width: this.width,
        modalCardHeader: this.modalCardHeader,
        modalCardHeaderIcon: this.modalCardHeaderIcon,
        modalCardConfirm: this.modalCardConfirm,
        onConfirm: () => {
          console.log('confirm')
        }
      });
    }
  }
}),{
  notes: 'A very very simple component',
});
