/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import ShDropdown from '../components/sh-dropdown/ShDropdown';
import ShDropdownItem from '../components/sh-dropdown/ShDropdownItem';
import ShButton from '../components/sh-button/ShButton';

const stories = storiesOf('Dropdown', module);
import IconsList from '../helpers/IconsList';
import centered from "@storybook/addon-centered";

const positions = {
  'top': 'top',
  'top-start': 'top-start',
  'top-end': 'top-end',
  'bottom': 'bottom',
  'bottom-start': 'bottom-start',
  'bottom-end': 'bottom-end',
  'left': 'left',
  'left-start': 'left-start',
  'left-end': 'left-end',
  'right': 'right',
  'right-start': 'right-start',
  'right-end': 'right-end',
};

const triggers = {
  'click': 'click',
  'hover': 'hover',
};

const boundaries = {
  'scrollParent': 'scrollParent',
  'window': 'window',
  'viewport': 'viewport',
};

const tooltipTypes = {
  'default':'default',
  'info':'info',
  'warning':'warning',
  'error':'error'
};

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Dropdown', () => ({
  components: {ShDropdown, ShDropdownItem, ShButton},
  data: () => {
    return {
      value: boolean('value',true),
      trigger: select('triggers', triggers, 'click'),
      delayOnMouseOver: text('delayOnMouseOver','10'),
      delayOnMouseOut: text('delayOnMouseOut','10'),
      boundariesElement: select('boundaries', boundaries, 'scrollParent'),
      position: select('position', positions, 'bottom-end'),
      forceShow: boolean('forceShow',false),
      forceHide: boolean('forceHide',false),
      appendToBody: boolean('appendToBody',false),
      visibleArrow: boolean('visibleArrow',false),
      stopPropagation: boolean('stopPropagation',false),
      preventDefault: boolean('preventDefault',false),
      mobileModal: boolean('is modal on mobile',false),
      disabled: boolean('disabled',false),
      hoverable: boolean('hoverable',false),
      itemDisabled: boolean('item disabled',false),
      paddingless: boolean('paddingless',false),
    }
  },
  template: `<sh-dropdown 
      v-model='value'
      :trigger='trigger'
      :disabled='disabled'
      :mobileModal='mobileModal'
      :position='position'
      :delayOnMouseOver='delayOnMouseOver'
      :delayOnMouseOut='delayOnMouseOut'
      :forceShow="forceShow"
      :forceHide="forceHide"
      :appendToBody="appendToBody"
      :visibleArrow="visibleArrow"
      :stopPropagation="stopPropagation"
      :preventDefault="preventDefault"
    >
    <sh-dropdown-item  :value='true' :disabled='itemDisabled' :paddingless='paddingless'>Action</sh-dropdown-item>
    <sh-dropdown-item separator='true'></sh-dropdown-item>
    <sh-dropdown-item :value='false' :paddingless='paddingless'  class=\"no-hover custom-item\">ddd</sh-dropdown-item>
    <sh-button slot='reference'
      buttonContent='Open'
    >
    </sh-button>
    </sh-dropdown>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very very simple component',
});

stories.add('Tooltip', () => ({
  components: {ShDropdown, ShDropdownItem, ShButton},
  data: () => {
    return {
      buttonContent: text('buttonContent','Open'),
      position: select('position', positions, 'is-top'),
      mobileModal: boolean('mobileModal',false),
      disabled: boolean('disabled',false),
      hoverable: boolean('hoverable',true),
      inline: boolean('inline',false),
      isTooltip: boolean('isTooltip',false),
      tooltipType: select('tooltipType', tooltipTypes, 'default'),
      tooltipIcon: select('tooltipIcon', IconsList, 'sh-icon-warning'),
      tooltipTitle: text('tooltipTitle','Lorem ipsum dolor sit amet enim.'),
      tooltipContent: text('tooltipContent','Lorem ipsum dolor sit amet enim. Etiam ullamcorper. Suspendisse a pellentesque dui, non felis. Maecenas malesuada elit lectus felis, malesuada ultricies.')
    }
  },
  template: "<sh-dropdown :disabled='disabled' :tooltipType='tooltipType' :isTooltip='isTooltip' :mobileModal='mobileModal' :position='position' :hoverable='hoverable' :inline='inline'>" +
    "<sh-button slot='trigger' " +
    ":buttonContent='buttonContent' " +
    ">" +
    "</sh-button>" +
      "<sh-dropdown-item :isTooltip='isTooltip' :tooltipIcon='tooltipIcon' :tooltipTitle='tooltipTitle' :tooltipContent='tooltipContent'>Action</sh-dropdown-item>" +
    "</sh-dropdown>",
  methods: {action: action('clicked')}
}),{
  notes: 'A very very simple component',
});
