/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import ShField from '../components/sh-field/ShField';
import ShFieldGroup from '../components/sh-field/ShFieldGroup';
import ShInput from '../components/sh-input/ShInput';
import centered from "@storybook/addon-centered";

const stories = storiesOf('Form', module);
const orientation = {
  'vertical': 'vertical',
  'horizontal': 'horizontal'
};
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Field', () => ({
  components: {ShField, ShInput},
  data: () => {
    return {
      name: text('name', 'inputName'),
      label: text('label', 'Label'),
      labelFor: text('labelFor', 'inputId'),
      horizontal: boolean('horizontal', false),
      newValue: 'Input value',
    }
  },
  template: `<ShField 
    :name='name' 
    :label='label' 
    :labelFor='labelFor'
    :horizontal='horizontal'>
      <ShInput
      v-model="newValue"
      inputType="text"
      :inputName="name"
      :id="labelFor"
      ></ShInput>
    </ShField>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very simple component',
});


stories.add('Field with description', () => ({
  components: {ShField, ShInput},
  data: () => {
    return {
      name: text('name', 'inputName'),
      label: text('label', 'Label'),
      labelFor: text('labelFor', 'inputId'),
      horizontal: boolean('horizontal', false),
      newValue: 'Input value',
    }
  },
  template: `<ShField 
    :name='name' 
    :label='label' 
    :labelFor='labelFor'
    :horizontal='horizontal'>
      <ShInput
      v-model="newValue"
      inputType="text"
      :inputName="name"
      :id="labelFor"
      ></ShInput>
      <p slot="description" class="sh-field-description">Description of form field element</p>
    </ShField>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very simple component',
});

stories.add('Field group', () => ({
  components: {ShField, ShFieldGroup, ShInput},
  data: () => {
    return {
      name: text('name', 'inputName'),
      label: text('label', 'Label'),
      horizontal: boolean('horizontal', false),
      newValue: 'Input value',
      newValue2: 'Input value 2',
    }
  },
  template: `<div>
    <ShFieldGroup :label='label'>
      <ShField 
      :name='name'
      class="sm-12 md-6 lg-5">
        <ShInput
        v-model="newValue"
        inputType="text"
        inputName="name"
        :id="labelFor"
        ></ShInput>
      </ShField>
      <ShField 
      :name='name'  
      class="sm-12 md-6 lg-5">
        <ShInput
        v-model="newValue2"
        inputType="text"
        inputName="name2"
        :id="labelFor"
        ></ShInput>
      </ShField>
    </ShFieldGroup>
  </div>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very simple component',
});