/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
withKnobs,
text,
boolean,
} from '@storybook/addon-knobs';

import ShHistory from '../components/sh-history/ShHistory';
import ShComment from '../components/sh-history/ShComment';
import ShCustomerData from '../components/sh-history/ShCustomerData';
import ShDropdown from '../components/sh-dropdown/ShDropdown';
import ShIcon from '../components/sh-icon/ShIcon';
import ShDropdownItem from '../components/sh-dropdown/ShDropdownItem';
import ShInput from '../components/sh-input/ShInput';

import ReadMore from '../directives/sh-read-more/sh-read-more'

import centered from "@storybook/addon-centered";

const checkboxGroupListTypeOptions = {
'inline': 'inline',
'block': 'block'
};

const stories = storiesOf('History', module);
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('History', () => ({
  components: {ShHistory, ShComment, ShCustomerData, ShDropdown, ShIcon, ShDropdownItem, ShInput},
  directives: {'read-more': ReadMore},
data: () => {
  return {
    name: text('name', 'Historia Klienta'),
    inputPlaceholder: text('inputPlaceholder', 'Dodaj komentarz...'),
    inputName: text('inputName', 'history'),
    buttonContent: text('buttonContent', 'Wyślij'),
    buttonContentEdit: text('buttonContent', 'Zapisz'),
    objectID: text('objectID', '0'),
    sectionID: text('sectionID', '0'),
    readMoreText: text('readMoreText', 'Zobacz więcej'),
    readLessText: text('readMoreText', 'Zobacz mniej'),
    activeSeeMore: boolean('activeSeeMore', false),
    isEditable: boolean('isEditable', true),
    commentAuthor: text('commentAuthor', 'Marcin Czerwiński'),
    editButton: text('editButton', 'Edytuj'),
    deleteButton: text('deleteButton', 'Usuń'),
    isShowMoreLoading: boolean('isShowMoreLoading', false),
    setDataItems: [
      {id: '1', type: '74', createdAt: '19/02/2019', updatedAt: '', content: 'Komentarz testowy'},
      {id: '2', type: '74', createdAt: '21/02/2029', updatedAt: '', content: 'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo. Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt. Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem.'},
      {id: '3', type: '1', createdAt: '19/02/2019', content: 'Karol zmienił status zamówienia nr #1010 z Nowe na Spakowane'},
      {id: '4', type: '1', createdAt: '21/02/2029', content: 'Chat on the subject of Połączenie kont użytkowmików'},
      {id: '5', type: '74', createdAt: '23/02/2049', updatedAt: '', content: 'To jest komentarz z backendu'},
      {id: '6', type: '1', createdAt: '23/02/2049', content: 'Michał złożył zamówienie nr #1010 na kwotę 61.00 zł'},
    ],
  }
},
template: `<div style="max-width: 800px">
  <ShHistory
  :name='name'
  :inputPlaceholder='inputPlaceholder'
  :inputName='inputName'
  :buttonContent='buttonContent'
  :sectionID='sectionID'
  :objectID='objectID'
  :isShowMoreVisible="true"
  :isShowMoreLoading="isShowMoreLoading"
  buttonShowMoreContent="Show more notifications"
  @onNewCommentCreate="createComment"
  @showMore="showMore"
  >
  <div slot='commentWrapper' class='data-wrapper'>
  <div v-for='item in setDataItems'>
  <ShCustomerData
  v-if="item.type === '1'" 
  :createdAt="item.createdAt">
    <span slot="content">
      {{ item.content }}
    </span>
  </ShCustomerData>
  <ShComment 
  v-else
  :readMoreText='readMoreText'
  :readLessText='readLessText'
  :activeSeeMore='activeSeeMore'
  :commentAuthor='commentAuthor'
  :editButton='editButton'
  :buttonContent='buttonContentEdit'
  :deleteButton='deleteButton'
  :isEditable='isEditable'
  :commentData='item'
  @onUpdateComment="edit">
  </ShComment>
  </div>
  </div>
  </ShHistory>
  </div>`,
  methods: {
    edit: action('clicked'),
    showMore: action('showMore'),
    createComment: action('createComment')
  }
}),{
notes: 'A very simple component',
});
