/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
} from '@storybook/addon-knobs';

import ShInput from '../components/sh-input/ShInput';
import IconsList from '../helpers/IconsList';
import {VMoney} from 'v-money';
import centered from "@storybook/addon-centered";

const stories = storiesOf('Input', module);

const inputTypesOptions = {
  'text': 'text',
  'number': 'number',
  'email': 'email',
  'password': 'password'
};
const inputSizeOptions = {
  'regular': '',
  'large': 'large'
};
const maskTypes = {
  'none': '',
  'money': {
    decimal: '.',
    thousands: '',
    prefix: '',
    suffix: '',
    precision: 2
  }
};
stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('ShInput', () => ({
  components: {ShInput},
  directives: {money: VMoney},
  data: () => {
    return {
      inputType: select('inputType', inputTypesOptions, ''),
      value: text('value', ''),
      inputSize: select('inputSize', inputSizeOptions, ''),
      inputName: text('inputName', 'inputName'),
      disabled: boolean('disabled', false),
      isReadonly: boolean('isReadonly', false),
      inputSuffix: text('inputSuffix', ''),
      inputPrefix: text('inputPrefix', ''),
      inputPlaceholder: text('inputPlaceholder', ''),
      mask: select('mask', maskTypes, ''),
    }
  },
  template: `<ShInput 
    :inputType="inputType"
    v-model="value"
    :inputName="inputName"
    :inputSize="inputSize"
    :disabled="disabled"
    :isReadonly="isReadonly"
    :inputSuffix="inputSuffix"
    :inputPrefix="inputPrefix"
    :inputPlaceholder="inputPlaceholder"
    v-money="mask">
    </ShInput>`,
  methods: {action: action('clicked')}
}),{
  notes: 'A very very simple component',
});
