/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue';
import {action} from '@storybook/addon-actions';
import { withBackgrounds } from '@storybook/addon-backgrounds';
import {
  withKnobs,
  text,
  number,
  boolean,
  select,
  array,
  object,
  color,
} from '@storybook/addon-knobs';

import ShTable from '../components/sh-table/ShTable';
import ShTableColumn from '../components/sh-table/ShTableColumn';
import ShIcon from '../components/sh-icon/ShIcon';
import ShButton from '../components/sh-button/ShButton';
import ShListPage from '../components/sh-list-page/ShListPage';
import TableDataApi from './tables/TableDataApi';
import ShCheckbox from '../components/sh-checkbox/ShCheckbox';
import i18n from '../../config/storybook/locale';



const stories = storiesOf('Table', module);
stories.addDecorator(
  withBackgrounds([
    { name: 'basic', value: '#FFFFFF', default: true },
    { name: 'blue', value: '#F5F8FB', default: false }
  ])
);

const tableDataSimple = [
  { 'id': 1, 'first_name': 'Jesse', 'last_name': 'Simmons', 'date': '2016-10-15 13:43:27', 'gender': 'Male' },
  { 'id': 2, 'first_name': 'John', 'last_name': 'Jacobs', 'date': '2016-12-15 06:00:53', 'gender': 'Male' },
  { 'id': 3, 'first_name': 'Tina', 'last_name': 'Gilbert', 'date': '2016-04-26 06:26:28', 'gender': 'Female' },
  { 'id': 4, 'first_name': 'Clarence', 'last_name': 'Flores', 'date': '2016-04-10 10:28:46', 'gender': 'Male' },
  { 'id': 5, 'first_name': 'Anne', 'last_name': 'Lee', 'date': '2016-12-06 14:38:38', 'gender': 'Female' }
];
const columns = [
  {
    field: 'id',
    label: 'ID',
    width: '40',
  },
  {
    field: 'first_name',
    label: 'First Name',
  },
  {
    field: 'last_name',
    label: 'Last Name',
  },
  {
    field: 'date',
    label: 'Date',
    centered: true
  },
  {
    field: 'gender',
    label: 'Gender',
  }
];

const columnsSorting = [
  {
    field: 'id',
    label: 'ID',
    width: '40',
    sortable: true
  },
  {
    field: 'first_name',
    label: 'First Name',
    sortable: true
  },
  {
    field: 'last_name',
    label: 'Last Name',
  },
  {
    field: 'date',
    label: 'Date',
    sortable: true
  },
  {
    field: 'gender',
    label: 'Gender',
  }
];

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('Table', () => ({
  components: {ShTable},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
      perPage: number('perPage', 20),
      currentPage: number('currentPage', 1),
      coloredHeader: boolean('coloredHeader', false),
      paginated: boolean('paginated', false),
      narrowed: boolean('narrowed', false),
      hoverable: boolean('hoverable', false),
      loading: boolean('loading', false),
      detailed: boolean('detailed', false),
      checkable: boolean('checkable', false),
      focusable: boolean('focusable', false),
    }
  },
  template: `<ShTable 
    :data='data'
    :columns='columns'
    :perPage='perPage'
    :currentPage='currentPage'
    :paginated='paginated'
    :narrowed='narrowed'
    :hoverable='hoverable'
    :loading='loading'
    :detailed='detailed'
    :checkable='checkable'
    :focusable='focusable'
    :coloredHeader='coloredHeader'
    >
    </ShTable>`,
  methods: {}
}),{
  notes: 'A very very simple component',
});

stories.add('Table empty state', () => ({
  components: {ShTable, ShIcon},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
      perPage: number('perPage', 20),
      currentPage: number('currentPage', 1),
      coloredHeader: boolean('coloredHeader', false),
      paginated: boolean('paginated', false),
      narrowed: boolean('narrowed', false),
      hoverable: boolean('hoverable', false),
      loading: boolean('loading', false),
      detailed: boolean('detailed', false),
      checkable: boolean('checkable', false),
      focusable: boolean('focusable', false),
    }
  },
  template: `<ShTable 
    :data='[]' 
    :columns='columns'
    :perPage='perPage'
    :currentPage='currentPage'
    :paginated='paginated'
    :narrowed='narrowed'
    :hoverable='hoverable'
    :loading='loading'
    :detailed='detailed'
    :checkable='checkable'
    :focusable='focusable'
    :coloredHeader='coloredHeader'
    >
     
    </ShTable>`,
  methods: {}
}),{
  notes: 'A very very simple component',
});

stories.add('Table with sorting', () => ({
  components: {ShTable},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columnsSorting,
      perPage: number('perPage', 20),
      currentPage: number('currentPage', 1),
      coloredHeader: boolean('coloredHeader', false),
      paginated: boolean('paginated', false),
      narrowed: boolean('narrowed', false),
      hoverable: boolean('hoverable', false),
      loading: boolean('loading', false),
      detailed: boolean('detailed', false),
      checkable: boolean('checkable', false),
      focusable: boolean('focusable', false),
    }
  },
  template: `<ShTable 
    :data='data' 
    :columns='columns'
    :perPage='perPage'
    :currentPage='currentPage'
    :paginated='paginated'
    :narrowed='narrowed'
    :hoverable='hoverable'
    :loading='loading'
    :detailed='detailed'
    :checkable='checkable'
    :focusable='focusable'
    :coloredHeader='coloredHeader'
    >
    </ShTable>`,
  methods: {}
}),{
  notes: 'A very very simple component',
});

stories.add('Table with pagination', () => ({
  components: {ShTable},
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
      perPage: number('perPage', 2),
      currentPage: number('currentPage', 1),
      coloredHeader: boolean('coloredHeader', false),
      paginated: boolean('paginated', true),
      narrowed: boolean('narrowed', false),
      hoverable: boolean('hoverable', true),
      loading: boolean('loading', false),
      detailed: boolean('detailed', false),
      checkable: boolean('checkable', false),
      focusable: boolean('focusable', false),
    }
  },
  template: `<ShTable 
    :data='data' 
    :columns='columns'
    :perPage='perPage'
    :currentPage='currentPage'
    :paginated='paginated'
    :narrowed='narrowed'
    :hoverable='hoverable'
    :loading='loading'
    :detailed='detailed'
    :checkable='checkable'
    :focusable='focusable'
    :coloredHeader='coloredHeader'
    >
    </ShTable>`,
  methods: {}
}),{
  notes: 'A very very simple component',
});

import TableSortable from '../helpers/TableSortableMixin';

stories.add('Table with sortable', () => ({
  components: {ShTable, ShTableColumn, ShIcon, ShButton},
  directives: { TableSortable },
  i18n: i18n,
  data: () => {
    return {
      data: tableDataSimple,
      columns: columns,
      perPage: number('perPage', 20),
      currentPage: number('currentPage', 1),
      coloredHeader: boolean('coloredHeader', false),
      paginated: boolean('paginated', false),
      narrowed: boolean('narrowed', false),
      hoverable: boolean('hoverable', false),
      loading: boolean('loading', false),
      detailed: boolean('detailed', false),
      checkable: boolean('checkable', false),
      focusable: boolean('focusable', false),
      sortableOptions: {
        handle: '.table-row-handle',
        animation: 200,
        draggable: 'tr',
      },
    }
  },
  template: `<ShTable 
    :draggable="true"
    :data="data" 
    :perPage="perPage"
    :currentPage="currentPage"
    :paginated="paginated"
    :narrowed="narrowed"
    :hoverable="hoverable"
    :loading="loading"
    :detailed="detailed"
    :checkable="checkable"
    :focusable="focusable"
    :coloredHeader="coloredHeader"
    >
     <template slot-scope="props">
      <ShTableColumn field="id" width="40" label="ID">
        {{ props.row.id }}
      </ShTableColumn>
      <ShTableColumn field="first_name" label="First name">
      {{ props.row.first_name }}
      <span class="additional-text">{{ props.row.gender }}</span>
      </ShTableColumn>
      <ShTableColumn field="last_name" label="Last name">
      {{ props.row.last_name }}
      </ShTableColumn>
      <ShTableColumn field="date" label="Date">
      {{ props.row.date }}
      </ShTableColumn>
      <ShTableColumn field="actions" label="Actions" align="right" class="sh-table-actions">
        <ShButton
        :isIcon="true"
        buttonIcon="sh-icon-edit"
        buttonSize="small"
        buttonColor="clear_gray"
        ></ShButton>
        <ShButton
        :isIcon="true"
        buttonIcon="sh-icon-eye"
        buttonSize="small"
        buttonColor="clear_gray"
        ></ShButton>
      </ShTableColumn>
    </template>
    </ShTable>`,
  methods: {}
}),{
  notes: 'A very very simple component',
});

import centered from "@storybook/addon-centered";


stories.add('Table orders from API', () => ({
  components: {TableDataApi},
  i18n: i18n,
  data: () => {
    return {

    }
  },
  template: `<TableDataApi></TableDataApi>`,
}),{
  notes: 'A very very simple component',
});
