/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  color
} from '@storybook/addon-knobs';

import ShTag from '../components/sh-tag/ShTag';
import ShTagButton from '../components/sh-tag/ShTagButton';
import IconsList from '../helpers/IconsList';
import centered from "@storybook/addon-centered";

const stories = storiesOf('Tag', module);
const tagColorOptions = {
  'blue': 'blue',
  'blue-light': 'blue-light',
  'blue-dark': 'blue-dark',
  'green': 'green',
  'green-light': 'green-light',
  'green-dark': 'green-dark',
  'red': 'red',
  'gray': 'gray',
  'gray-light': 'gray-light',
  'gray-dark': 'gray-dark',
  'orange': 'orange',
  'pink': 'pink',
  'pink-light': 'pink-light',
  'purple': 'purple'
};
const buttonIconOptions = {
  'none': '',
  'arrow-back': 'sh-icon-arrow-back',
  'add': 'sh-icon-add',
  'search': 'sh-icon-search'
};
const buttonTypeOptions = {
  'button': 'button',
  'submit': 'submit'
};
const buttonSizeOptions = {
  'regular': '',
  'small': 'small'
};

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('ShTag', () => ({
  components: {ShTag},
  data: () => {
    return {
      tagContent: text('tagContent', 'tag'),
      tagColor: select('tagColor', tagColorOptions, 'blue'),
      isCloseable: boolean('isCloseable', false),
      isLoading: boolean('isLoading', false),
      isStockIndicator: boolean('isStockIndicator', false),
      isInStock: boolean('isInStock', false),

    }
  },
  template: "<ShTag " +
    ":tagContent='tagContent' " +
    ":tagColor='tagColor' " +
    ":isCloseable='isCloseable' " +
    ":isStockIndicator='isStockIndicator'" +
    ":isInStock='isInStock'" +
    ":isLoading='isLoading'" +
    "@deleteTag='action'" +
    ">" +
    "</ShTag>",
  methods: { action: action('clicked') },
}),{
  notes: 'A very simple component',
});

stories.add('ShTagButton', () => ({
  components: {ShTagButton},
  data: () => {
    return {
      tagContent: text('tagContent', 'tag'),
      // tagColor: select('tagColor', tagColorOptions, 'blue'),
      colorPreview: color('colorPreview', ''),
      isCloseable: boolean('isCloseable', false),
      isEditable: boolean('isEditable', false),
      isDragable: boolean('isDragable', false),
      hasAttachment: boolean('hasAttachment', false),
      attachmentIcon: select('attachmentIcon', IconsList, ''),
      // isStockIndicator: boolean('isStockIndicator', false),
      // isInStock: boolean('isInStock', false)
    }
  },
  template: "<ShTagButton " +
    ":tagContent='tagContent' " +
    ":isCloseable='isCloseable' " +
    ":isEditable='isEditable' " +
    ":colorPreview='colorPreview' " +
    ":isDragable='isDragable' " +
    ":hasAttachment='hasAttachment' " +
    ":attachmentIcon='attachmentIcon'" +
    "@attachmentClicked='action'" +
    "@attachmentHovered='attachmentHovered'" +
    "@editClicked='editClicked'" +
    "@deleteClicked='deleteClicked'" +
    ">" +
    "</ShTagButton>",
  methods: {
    action: action('attachmentClicked'),
    attachmentHovered: action('attachmentHovered'),
    editClicked: action('editClicked'),
    deleteClicked: action('deleteClicked'),
  },
}),{
  notes: 'A very simple component',
});
