import _Vue from 'vue';

export declare type ShDialogConfig = {
    /**
     * Dialog title
     */
    title?: string;

    /**
     * Message text
     */
    message: string;

    /**
     * Adds an icon on the left side depending on the <code>type</code> or <code>icon</code>
     */
    hasIcon?: boolean;

    /**
     * Icon name if <code>hasIcon</code>, optional
     */
    icon?: string;

    /**
     * Icon pack to use if <code>hasIcon</code>, optional
     */
    iconPack?: string;

    /**
     * Dialog\'s size, optional
     */
    size?: 'is-small' | 'is-medium' | 'is-large';

    /**
     * Custom animation (transition name)
     */
    animation?: string;

    /**
     * Text of the confirm button
     */
    confirmText?: string;

    /**
     * Text of the cancel button
     */
    cancelText?: string;

    /**
     * Can close dialog by clicking cancel button, pressing escape or clicking outside
     */
    canCancel?: boolean | Array<any>;

    /**
     * Callback function when the confirm button is clicked
     */
    onConfirm?: (value: string) => any;

    /**
     * Callback function when the dialog is canceled (cancel button is clicked / pressed escape / clicked outside)
     */
    onCancel?: () => any;

    /**
     * Type (color) of the confirm button (and the icon if <code>hasIcon</code>)
     */
    type?: any;

    /**
     * <code>clip</code> to remove the <code>&lt;body&gt;</code> scrollbar, <code>keep</code> to have a non scrollable scrollbar
     * to avoid shifting background, but will set <code>&lt;body&gt;</code> to position fixed, might break some layouts
     */
    scroll?: 'clip' | 'keep';
}

type ShPromptDialogConfig = ShDialogConfig & {
    /**
     * Prompt only: input's attributes
     */
    inputAttrs?: any;
};

export declare const ShDialog: {
  alert: (params: ShDialogConfig | string) => any;
  confirm: (params: ShDialogConfig) => any;
  prompt: (params: ShPromptDialogConfig) => any;
}

declare type ShModalConfig = {
  content?: string;
  component?: typeof _Vue;
  parent?: _Vue;
  props?: any;
  events?: {
    [index: string]: Function
  };
  width?: string | number;
  hasModalCard?: boolean;
  animation?: string;
  canCancel?: boolean | Array<any>;
  onCancel?: () => any;
  scroll?: 'clip' | 'keep';
}

export declare const ShModalProgrammatic: {
  open: (params: ShModalConfig | string) => any;
}
